@@ -2,8 +2,11 @@ from investing_algorithm_framework.core.market_services.market_service \
     import MarketService
 from investing_algorithm_framework.core.market_services.binance_market_service \
     import BinanceMarketService
+from investing_algorithm_framework.core.market_services.factory import \
+    DefaultMarketServiceFactory
 
 __all__ = [
     "MarketService",
-    "BinanceMarketService"
+    "BinanceMarketService",
+    "DefaultMarketServiceFactory"
 ]
